@@ -1,7 +1,6 @@
 import os
-from shutil import copy, copyfile
+from shutil import copy
 import subprocess
-from datetime import datetime
 
 
 
@@ -50,8 +49,8 @@ def generate_pymol(xyz_directory):
 
     os.chdir(xyz_folder_path)
     print("Directory Changed")
-    # subprocess.Popen("mGenerate_PyMOL_Session.py", cwd=None, shell= True)
-    subprocess.Popen("mGenerate_PyMOL_Session.py", cwd=None, shell= True)
+    # subprocess.Popen("mGenerate_PyMOL_Session.sh", cwd=None, shell= True)
+    subprocess.Popen("mGenerate_PyMOL_Session.sh", cwd=None, shell= True)
 
 
 # testing function
